@@ -2,13 +2,15 @@ import re
 import sys
 import pathlib
 import inspect
-import typing
+from typing import Dict, List, Optional, Any
+import warnings
 
 import yaml
 
-from . import plugins as standard_plugins
+import webviz_config.plugins
 from .utils import terminal_colors
 from .utils._get_webviz_plugins import _get_webviz_plugins
+from . import _deprecation_store as _ds
 
 SPECIAL_ARGS = ["self", "app", "webviz_settings", "_call_signature"]
 
@@ -17,9 +19,9 @@ def _call_signature(
     plugin_name: str,
     kwargs: dict,
     config_folder: pathlib.Path,
-    contact_person: typing.Optional[dict] = None,
+    contact_person: Optional[dict] = None,
 ) -> tuple:
-    # pylint: disable=too-many-branches,too-many-statements
+    # pylint: disable=too-many-branches,too-many-statements,too-many-locals
     """Takes as input the name of a plugin together with user given arguments
     (originating from the configuration file). Returns the equivalent Python code wrt.
     initiating an instance of that plugin (with the given arguments).
@@ -31,7 +33,9 @@ def _call_signature(
       * If there is type mismatch between user given argument value, and type
         hint in __init__ signature (given that type hint exist)
     """
-    argspec = inspect.getfullargspec(getattr(standard_plugins, plugin_name).__init__)
+    argspec = inspect.getfullargspec(
+        getattr(webviz_config.plugins, plugin_name).__init__
+    )
 
     if argspec.defaults is not None:
         required_args = argspec.args[: -len(argspec.defaults)]
@@ -90,7 +94,7 @@ def _call_signature(
 
             if expected_type == pathlib.Path:
                 kwargs[arg] = (config_folder / pathlib.Path(kwargs[arg])).resolve()
-            elif expected_type == typing.List[pathlib.Path]:
+            elif expected_type == List[pathlib.Path]:
                 kwargs[arg] = [
                     (config_folder / pathlib.Path(patharg)).resolve()
                     for patharg in kwargs[arg]
@@ -110,6 +114,76 @@ def _call_signature(
             except TypeError:
                 pass
 
+    kwargs_including_defaults = kwargs
+    deprecation_warnings = []
+
+    deprecated_plugin = _ds.DEPRECATION_STORE.get_stored_plugin_deprecation(
+        getattr(webviz_config.plugins, plugin_name)
+    )
+    if deprecated_plugin:
+        deprecation_warnings.append(deprecated_plugin.short_message)
+
+    deprecations = _ds.DEPRECATION_STORE.get_stored_plugin_argument_deprecations(
+        getattr(webviz_config.plugins, plugin_name).__init__
+    )
+
+    signature = inspect.signature(getattr(webviz_config.plugins, plugin_name).__init__)
+    for key, value in signature.parameters.items():
+        if value.default is not inspect.Parameter.empty and key not in kwargs.keys():
+            kwargs_including_defaults[key] = value.default
+
+    for deprecation in deprecations:
+        if isinstance(deprecation, _ds.DeprecatedArgument):
+            if deprecation.argument_name in kwargs_including_defaults.keys():
+                deprecation_warnings.append(deprecation.short_message)
+                warnings.warn(
+                    """Deprecated Argument: {} with value '{}' in method {} in module {}
+------------------------
+{}
+===
+{}
+""".format(
+                        deprecation.argument_name,
+                        kwargs_including_defaults[deprecation.argument_name],
+                        deprecation.method_name,
+                        getattr(deprecation.method_reference, "__module__"),
+                        deprecation.short_message,
+                        deprecation.long_message,
+                    ),
+                    FutureWarning,
+                )
+        elif isinstance(deprecation, _ds.DeprecatedArgumentCheck):
+            mapped_args: Dict[str, Any] = {}
+            for arg in deprecation.argument_names:
+                for name, value in kwargs_including_defaults.items():
+                    if arg == name:
+                        mapped_args[arg] = value
+                        break
+
+            result = deprecation.callback(**mapped_args)  # type: ignore
+            if result:
+                deprecation_warnings.append(result[0])
+                warnings.warn(
+                    """Deprecated Argument(s): {} with value '{}' in method {} in module {}
+------------------------
+{}
+===
+{}
+""".format(
+                        deprecation.argument_names,
+                        [
+                            value
+                            for key, value in kwargs_including_defaults.items()
+                            if key in deprecation.argument_names
+                        ],
+                        deprecation.method_name,
+                        getattr(deprecation.method_reference, "__module__"),
+                        result[0],
+                        result[1],
+                    ),
+                    FutureWarning,
+                )
+
     special_args = ""
     if "app" in argspec.args:
         special_args += "app=app, "
@@ -118,7 +192,10 @@ def _call_signature(
 
     return (
         f"{plugin_name}({special_args}**{kwargs})",
-        f"plugin_layout(contact_person={contact_person})",
+        (
+            f"plugin_layout(contact_person={contact_person}"
+            f", deprecation_warnings={deprecation_warnings})"
+        ),
     )
 
 
@@ -128,7 +205,9 @@ class ParserError(Exception):
 
 class ConfigParser:
 
-    STANDARD_PLUGINS = [name for (name, _) in _get_webviz_plugins(standard_plugins)]
+    STANDARD_PLUGINS = [
+        name for (name, _) in _get_webviz_plugins(webviz_config.plugins)
+    ]
 
     def __init__(self, yaml_file: pathlib.Path):
 
@@ -153,8 +232,9 @@ class ConfigParser:
             ).with_traceback(sys.exc_info()[2])
 
         self._config_folder = pathlib.Path(yaml_file).parent
-        self._page_ids: typing.List[str] = []
+        self._page_ids: List[str] = []
         self._assets: set = set()
+        self._plugin_metadata: Dict[str, dict] = {}
         self._used_plugin_packages: set = set()
         self.clean_configuration()
 
@@ -283,7 +363,10 @@ class ConfigParser:
                     self._config_folder,
                 )
 
-                self.assets.update(getattr(standard_plugins, plugin_name).ASSETS)
+                self._assets.update(getattr(webviz_config.plugins, plugin_name).ASSETS)
+                self._plugin_metadata[
+                    plugin_name
+                ] = webviz_config.plugins.PLUGIN_METADATA[plugin_name]
 
     @property
     def configuration(self) -> dict:
@@ -296,3 +379,10 @@ class ConfigParser:
     @property
     def assets(self) -> set:
         return self._assets
+
+    @property
+    def plugin_metadata(self) -> Dict[str, dict]:
+        """Returns a dictionary of plugin metadata, and only for
+        plugins included in the configuration file.
+        """
+        return self._plugin_metadata
